@@ -31,9 +31,10 @@ from monasca_persister.repositories.utils import parse_measurement_message
 
 LOG = log.getLogger(__name__)
 
-MEASUREMENT_INSERT_CQL = ('update monasca.measurements USING TTL ? '
-                          'set value = ?, value_meta = ?, region = ?, tenant_id = ?, metric_name = ?, dimensions = ? '
-                          'where metric_id = ? and time_stamp = ?')
+MEASUREMENT_INSERT_CQL = (
+    'update monasca.measurements USING TTL ? '
+    'set value = ?, value_meta = ?, region = ?, tenant_id = ?, metric_name = ?, dimensions = ? '
+    'where metric_id = ? and time_stamp = ?')
 
 MEASUREMENT_UPDATE_CQL = ('update monasca.measurements USING TTL ? '
                           'set value = ?, value_meta = ? where metric_id = ? and time_stamp = ?')
@@ -66,8 +67,16 @@ RETRIEVE_METRIC_DIMENSION_CQL = ('select region, tenant_id, metric_name, '
                                  'WHERE token(region, tenant_id, metric_name) > ? '
                                  'and token(region, tenant_id, metric_name) <= ? ')
 
-Metric = namedtuple('Metric', ['id', 'region', 'tenant_id', 'name', 'dimension_list', 'dimension_names',
-                               'time_stamp', 'value', 'value_meta'])
+Metric = namedtuple('Metric',
+                    ['id',
+                     'region',
+                     'tenant_id',
+                     'name',
+                     'dimension_list',
+                     'dimension_names',
+                     'time_stamp',
+                     'value',
+                     'value_meta'])
 
 
 class MetricCassandraRepository(abstract_repository.AbstractCassandraRepository):
@@ -101,7 +110,10 @@ class MetricCassandraRepository(abstract_repository.AbstractCassandraRepository)
 
         self._retrieve_metric_dimension_stmt = self._session.prepare(RETRIEVE_METRIC_DIMENSION_CQL)
 
-        self._metric_batch = MetricBatch(self._cluster.metadata, self._cluster.load_balancing_policy, self._max_batches)
+        self._metric_batch = MetricBatch(
+            self._cluster.metadata,
+            self._cluster.load_balancing_policy,
+            self._max_batches)
 
         self._metric_id_cache = LRUCache(self._cache_size)
         self._dimension_cache = LRUCache(self._cache_size)
@@ -178,34 +190,29 @@ class MetricCassandraRepository(abstract_repository.AbstractCassandraRepository)
                     self._metric_batch.add_dimension_query(dimension_bound_stmt)
                     self._dimension_cache[dim_key] = dim_key
 
-                metric_dim_key = self._get_metric_dimnesion_key(metric.region, metric.tenant_id, metric.name, name,
-                                                                value)
+                metric_dim_key = self._get_metric_dimnesion_key(
+                    metric.region, metric.tenant_id, metric.name, name, value)
                 if not self._metric_dimension_cache.get(metric_dim_key, None):
-                    dimension_metric_bound_stmt = self._dimension_metric_stmt.bind((metric.region,
-                                                                                    metric.tenant_id,
-                                                                                    name,
-                                                                                    value,
-                                                                                    metric.name))
+                    dimension_metric_bound_stmt = self._dimension_metric_stmt.bind(
+                        (metric.region, metric.tenant_id, name, value, metric.name))
                     self._metric_batch.add_dimension_metric_query(dimension_metric_bound_stmt)
 
-                    metric_dimension_bound_stmt = self._metric_dimension_stmt.bind((metric.region,
-                                                                                    metric.tenant_id,
-                                                                                    metric.name,
-                                                                                    name,
-                                                                                    value))
+                    metric_dimension_bound_stmt = self._metric_dimension_stmt.bind(
+                        (metric.region, metric.tenant_id, metric.name, name, value))
                     self._metric_batch.add_metric_dimension_query(metric_dimension_bound_stmt)
 
                     self._metric_dimension_cache[metric_dim_key] = metric_dim_key
 
-            measurement_insert_bound_stmt = self._measurement_insert_stmt.bind((self._retention,
-                                                                                metric.value,
-                                                                                metric.value_meta,
-                                                                                metric.region,
-                                                                                metric.tenant_id,
-                                                                                metric.name,
-                                                                                metric.dimension_list,
-                                                                                id_bytes,
-                                                                                metric.time_stamp))
+            measurement_insert_bound_stmt = self._measurement_insert_stmt.bind(
+                (self._retention,
+                 metric.value,
+                 metric.value_meta,
+                 metric.region,
+                 metric.tenant_id,
+                 metric.name,
+                 metric.dimension_list,
+                 id_bytes,
+                 metric.time_stamp))
             self._metric_batch.add_measurement_query(measurement_insert_bound_stmt)
 
             return metric
@@ -240,7 +247,9 @@ class MetricCassandraRepository(abstract_repository.AbstractCassandraRepository)
             key = self._get_dimnesion_key(row.region, row.tenant_id, row.name, row.value)
             self._dimension_cache[key] = key
 
-        LOG.info("loaded %s dimension entries cache from database into cache." % self._dimension_cache.currsize)
+        LOG.info(
+            "loaded %s dimension entries cache from database into cache." %
+            self._dimension_cache.currsize)
 
     @staticmethod
     def _get_dimnesion_key(region, tenant_id, name, value):
@@ -258,16 +267,22 @@ class MetricCassandraRepository(abstract_repository.AbstractCassandraRepository)
 
         cnt = 0
         for row in rows:
-            key = self._get_metric_dimnesion_key(row.region, row.tenant_id, row.metric_name, row.dimension_name,
-                                                 row.dimension_value)
+            key = self._get_metric_dimnesion_key(
+                row.region,
+                row.tenant_id,
+                row.metric_name,
+                row.dimension_name,
+                row.dimension_value)
             self._metric_dimension_cache[key] = key
             cnt += 1
 
         LOG.info("loaded %s metric dimension entries from database into cache." % cnt)
         LOG.info(
-            "total loaded %s metric dimension entries in cache." % self._metric_dimension_cache.currsize)
+            "total loaded %s metric dimension entries in cache." %
+            self._metric_dimension_cache.currsize)
 
     @staticmethod
     def _get_metric_dimnesion_key(region, tenant_id, metric_name, dimension_name, dimension_value):
 
-        return '%s\0%s\0%s\0%s\0%s' % (region, tenant_id, metric_name, dimension_name, dimension_value)
+        return '%s\0%s\0%s\0%s\0%s' % (region, tenant_id, metric_name,
+                                       dimension_name, dimension_value)
